import { IResponseWithSync, AccelbyteSDK, ApiArgs, IResponse } from '@accelbyte/sdk';
import { AxiosInstance } from 'axios';
import { z } from 'zod';

declare const RetrieveTimeResponse: z.ZodObject<{
    currentTime: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    currentTime?: string | null | undefined;
}, {
    currentTime?: string | null | undefined;
}>;
interface RetrieveTimeResponse extends z.TypeOf<typeof RetrieveTimeResponse> {
}

/**
 * AUTO GENERATED
 */

declare class Misc$ {
    private axiosInstance;
    private namespace;
    private cache;
    constructor(axiosInstance: AxiosInstance, namespace: string, cache?: boolean);
    /**
     * Get server time
     */
    getMiscTime(): Promise<IResponseWithSync<RetrieveTimeResponse>>;
    /**
     * List languages.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: language list&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscLanguages(): Promise<IResponseWithSync<unknown>>;
    /**
     * List time zones.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: time zones&lt;/li&gt;&lt;/ul&gt;
     */
    getMiscTimezones(): Promise<IResponseWithSync<unknown>>;
}

/**
 * AUTO GENERATED
 */

declare function MiscApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getMiscTime: () => Promise<RetrieveTimeResponse>;
    getMiscLanguages: () => Promise<unknown>;
    getMiscTimezones: () => Promise<unknown>;
};

declare const NamespaceInfoArray: z.ZodArray<z.ZodObject<{
    clientId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    displayName: z.ZodString;
    namespace: z.ZodString;
    parentNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "DELETED", "INACTIVE"]>>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}>, "many">;
interface NamespaceInfoArray extends z.TypeOf<typeof NamespaceInfoArray> {
}

declare const NamespacePublisherInfo: z.ZodObject<{
    publisher: z.ZodNullable<z.ZodOptional<z.ZodBoolean>>;
    publisherNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    publisher?: boolean | null | undefined;
    publisherNamespace?: string | null | undefined;
}, {
    publisher?: boolean | null | undefined;
    publisherNamespace?: string | null | undefined;
}>;
interface NamespacePublisherInfo extends z.TypeOf<typeof NamespacePublisherInfo> {
}

/**
 * AUTO GENERATED
 */

declare class Namespace$ {
    private axiosInstance;
    private namespace;
    private cache;
    constructor(axiosInstance: AxiosInstance, namespace: string, cache?: boolean);
    /**
     * Get all namespaces.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: login user&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11303&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: list of namespaces&lt;/li&gt;&lt;/ul&gt;
     */
    getNamespaces(queryParams?: {
        activeOnly?: boolean | null;
    }): Promise<IResponseWithSync<NamespaceInfoArray>>;
    /**
     * Get namespace info related publisher namespace.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:NAMESPACE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(READ)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11305&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Namespace info related publisher namespace&lt;/li&gt;&lt;/ul&gt;
     */
    getPublisher(): Promise<IResponseWithSync<NamespacePublisherInfo>>;
}

/**
 * AUTO GENERATED
 */

declare function NamespaceApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getNamespaces: (queryParams?: {
        activeOnly?: boolean | null | undefined;
    } | undefined) => Promise<NamespaceInfoArray>;
    getPublisher: () => Promise<NamespacePublisherInfo>;
};

declare const UserProfileCreate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
}>;
interface UserProfileCreate extends z.TypeOf<typeof UserProfileCreate> {
}

declare const UserProfileInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
    zipCode?: string | null | undefined;
}, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
    zipCode?: string | null | undefined;
}>;
interface UserProfileInfo extends z.TypeOf<typeof UserProfileInfo> {
}

declare const UserProfilePrivateCreate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}>;
interface UserProfilePrivateCreate extends z.TypeOf<typeof UserProfilePrivateCreate> {
}

declare const UserProfilePrivateInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}>;
interface UserProfilePrivateInfo extends z.TypeOf<typeof UserProfilePrivateInfo> {
}

declare const UserProfilePublicInfo: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>;
interface UserProfilePublicInfo extends z.TypeOf<typeof UserProfilePublicInfo> {
}

declare const UserProfilePublicInfoArray: z.ZodArray<z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    publicId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    timeZone?: string | null | undefined;
    publicId?: string | null | undefined;
    userId?: string | null | undefined;
}>, "many">;
interface UserProfilePublicInfoArray extends z.TypeOf<typeof UserProfilePublicInfoArray> {
}

declare const UserProfileStatusUpdate: z.ZodObject<{
    status: z.ZodEnum<["ACTIVE", "INACTIVE"]>;
}, "strip", z.ZodTypeAny, {
    status: "ACTIVE" | "INACTIVE";
}, {
    status: "ACTIVE" | "INACTIVE";
}>;
interface UserProfileStatusUpdate extends z.TypeOf<typeof UserProfileStatusUpdate> {
}

declare const UserProfileUpdate: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}, {
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}>;
interface UserProfileUpdate extends z.TypeOf<typeof UserProfileUpdate> {
}

declare const UserZipCode: z.ZodObject<{
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    zipCode?: string | null | undefined;
}, {
    zipCode?: string | null | undefined;
}>;
interface UserZipCode extends z.TypeOf<typeof UserZipCode> {
}

declare const UserZipCodeUpdate: z.ZodObject<{
    zipCode: z.ZodString;
}, "strip", z.ZodTypeAny, {
    zipCode: string;
}, {
    zipCode: string;
}>;
interface UserZipCodeUpdate extends z.TypeOf<typeof UserZipCodeUpdate> {
}

/**
 * AUTO GENERATED
 */

declare class UserProfile$ {
    private axiosInstance;
    private namespace;
    private cache;
    constructor(axiosInstance: AxiosInstance, namespace: string, cache?: boolean);
    /**
     * Get user public profile by ids.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11405&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profiles&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublic(queryParams: {
        userIds: string | null;
    }): Promise<IResponseWithSync<UserProfilePublicInfoArray>>;
    /**
     * Get my profile&lt;br&gt;&lt;b&gt;Client with user token can get user profile in target namespace&lt;/b&gt;&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(READ)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to get &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to get &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfiles(): Promise<IResponseWithSync<UserProfilePrivateInfo>>;
    /**
     * Create my profile.&lt;br&gt;&lt;b&gt;Client with user token can create user profile in target namespace&lt;/b&gt;&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=1 &lt;b&gt;(CREATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11401&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Created user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to create &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to create &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Country&lt;/i&gt; : ISO3166-1 alpha-2 two letter, e.g. US &lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    createUserMeProfile(data: UserProfilePrivateCreate): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Update my profile.&lt;br&gt;Updates user profile in the target namespace (namespace in the path). If token&#39;s namespace doesn&#39;t match the target namespace, the service automatically maps the token&#39;s user ID into the user ID in the target namespace. The endpoint returns the updated user profile on a successful call.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;li&gt;&lt;i&gt;Path&#39;s namespace&lt;/i&gt; : &lt;ul&gt;&lt;li&gt;can be filled with &lt;b&gt;publisher namespace&lt;/b&gt; in order to update &lt;b&gt;publisher user profile&lt;/b&gt;&lt;/li&gt;&lt;li&gt;can be filled with &lt;b&gt;game namespace&lt;/b&gt; in order to update &lt;b&gt;game user profile&lt;/b&gt;&lt;/li&gt;&lt;/ul&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;/ul&gt;
     */
    updateUserMeProfile(data: UserProfileUpdate): Promise<IResponse<UserProfilePrivateInfo>>;
    /**
     * Get user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(READ)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfiles_ByUserId(userId: string): Promise<IResponseWithSync<UserProfileInfo>>;
    /**
     * Create user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:PROFILE&#34;&lt;/b&gt;, action=1 &lt;b&gt;(CREATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11401&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Created user profile&lt;/li&gt;&lt;/ul&gt;
     */
    createProfile_ByUserId(userId: string, data: UserProfileCreate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Update user profile.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Language&lt;/i&gt; : allowed format: en, en-US&lt;/li&gt;&lt;li&gt;&lt;i&gt;Timezone&lt;/i&gt; : IANA time zone, e.g. Asia/Shanghai&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated user profile&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfile_ByUserId(userId: string, data: UserProfileUpdate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Get my zip code.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(READ)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11407&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user zip code&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfilesZipCode(): Promise<IResponseWithSync<UserZipCode>>;
    /**
     * Update my zip code.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11408&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user zip code&lt;/li&gt;&lt;/ul&gt;
     */
    patchUserMeProfileZipCode(data: UserZipCodeUpdate): Promise<IResponse<UserZipCode>>;
    /**
     * Get user public profile by public id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublicByPublicId(queryParams: {
        publicId: string | null;
    }): Promise<IResponseWithSync<UserProfilePublicInfo>>;
    /**
     * Get user profile public info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11404&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user public profile&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesPublic_ByUserId(userId: string): Promise<IResponseWithSync<UserProfilePublicInfo>>;
    /**
     * Update user profile status.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11406&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user profile&lt;/li&gt;&lt;/ul&gt;
     */
    patchProfileStatus_ByUserId(userId: string, data: UserProfileStatusUpdate): Promise<IResponse<UserProfileInfo>>;
    /**
     * Get custom attributes info.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11404&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: user custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    getProfilesCustomAttributes_ByUserId(userId: string): Promise<IResponseWithSync<unknown>>;
    /**
     * Update partially custom attributes tied to user id.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt; : allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateProfileCustomAttribute_ByUserId(userId: string, data: any): Promise<IResponse<unknown>>;
    /**
     * Get my private custom attributes.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=2 &lt;b&gt;(READ)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: custom attributes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11403&lt;/li&gt;&lt;/ul&gt;
     */
    getUsersMeProfilesPrivateCustomAttributes(): Promise<IResponseWithSync<unknown>>;
    /**
     * Update partially private custom attributes tied to me.&lt;br&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&lt;b&gt;&#34;NAMESPACE:{namespace}:PROFILE&#34;&lt;/b&gt;, action=4 &lt;b&gt;(UPDATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11402&lt;/li&gt;&lt;li&gt;&lt;i&gt;Request body&lt;/i&gt;: allowed format: JSON object&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: Updated custom attributes&lt;/li&gt;&lt;/ul&gt;
     */
    updateUserMeProfilePrivateCustomAttribute(data: any): Promise<IResponse<unknown>>;
}

/**
 * AUTO GENERATED
 */

declare function UserProfileApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    getProfilesPublic: (queryParams: {
        userIds: string | null;
    }) => Promise<UserProfilePublicInfoArray>;
    getUsersMeProfiles: () => Promise<UserProfilePrivateInfo>;
    createUserMeProfile: (data: UserProfilePrivateCreate) => Promise<UserProfilePrivateInfo>;
    updateUserMeProfile: (data: UserProfileUpdate) => Promise<UserProfilePrivateInfo>;
    getProfiles_ByUserId: (userId: string) => Promise<UserProfileInfo>;
    createProfile_ByUserId: (userId: string, data: UserProfileCreate) => Promise<UserProfileInfo>;
    updateProfile_ByUserId: (userId: string, data: UserProfileUpdate) => Promise<UserProfileInfo>;
    getUsersMeProfilesZipCode: () => Promise<UserZipCode>;
    patchUserMeProfileZipCode: (data: UserZipCodeUpdate) => Promise<UserZipCode>;
    getProfilesPublicByPublicId: (queryParams: {
        publicId: string | null;
    }) => Promise<UserProfilePublicInfo>;
    getProfilesPublic_ByUserId: (userId: string) => Promise<UserProfilePublicInfo>;
    patchProfileStatus_ByUserId: (userId: string, data: UserProfileStatusUpdate) => Promise<UserProfileInfo>;
    getProfilesCustomAttributes_ByUserId: (userId: string) => Promise<unknown>;
    updateProfileCustomAttribute_ByUserId: (userId: string, data: any) => Promise<unknown>;
    getUsersMeProfilesPrivateCustomAttributes: () => Promise<unknown>;
    updateUserMeProfilePrivateCustomAttribute: (data: any) => Promise<unknown>;
};

declare const FileUploadUrlInfo: z.ZodObject<{
    accessUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    contentType: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    method: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    url: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    accessUrl?: string | null | undefined;
    contentType?: string | null | undefined;
    method?: string | null | undefined;
    url?: string | null | undefined;
}, {
    accessUrl?: string | null | undefined;
    contentType?: string | null | undefined;
    method?: string | null | undefined;
    url?: string | null | undefined;
}>;
interface FileUploadUrlInfo extends z.TypeOf<typeof FileUploadUrlInfo> {
}

/**
 * AUTO GENERATED
 */

declare class FileUpload$ {
    private axiosInstance;
    private namespace;
    private cache;
    constructor(axiosInstance: AxiosInstance, namespace: string, cache?: boolean);
    /**
     * Generate an upload URL for user content. It&#39;s valid for 10 minutes.&lt;br/&gt;There are 2 kinds of storage limitation per user : maximum file count and maximum file size.&lt;br/&gt;The threshold of those limitations is different between upload category that is used.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource = &lt;b&gt;&#34;NAMESPACE:{namespace}:USER:{userId}:FILEUPLOAD&#34;&lt;/b&gt;, action=1 &lt;b&gt;(CREATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11102&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file count per user&lt;/i&gt;: 10 files&lt;/li&gt;&lt;li&gt;&lt;i&gt;Default maximum file size per user&lt;/i&gt;: 104857600 bytes&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByUserId(userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
    /**
     * Generate an upload URL. It&#39;s valid for 10 minutes.&lt;br/&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource = &lt;b&gt;&#34;NAMESPACE:{namespace}:FILEUPLOAD&#34;&lt;/b&gt;, action=1 &lt;b&gt;(CREATE)&lt;/b&gt;&lt;/li&gt;&lt;li&gt;&lt;i&gt;Action code&lt;/i&gt;: 11101&lt;/li&gt;&lt;li&gt;&lt;i&gt;Returns&lt;/i&gt;: URL data&lt;/li&gt;&lt;/ul&gt;
     */
    createFile_ByFolder(folder: string, queryParams: {
        fileType: string | null;
    }): Promise<IResponse<FileUploadUrlInfo>>;
}

/**
 * AUTO GENERATED
 */

declare function FileUploadApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createFile_ByUserId: (userId: string, queryParams: {
        fileType: string | null;
        category?: string | null;
    }) => Promise<FileUploadUrlInfo>;
    createFile_ByFolder: (folder: string, queryParams: {
        fileType: string | null;
    }) => Promise<FileUploadUrlInfo>;
};

declare const UserReportRequest: z.ZodObject<{
    category: z.ZodString;
    description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    gameSessionId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    subcategory: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodString;
}, "strip", z.ZodTypeAny, {
    description?: string | null | undefined;
    gameSessionId?: string | null | undefined;
    subcategory?: string | null | undefined;
    userId: string;
    category: string;
}, {
    description?: string | null | undefined;
    gameSessionId?: string | null | undefined;
    subcategory?: string | null | undefined;
    userId: string;
    category: string;
}>;
interface UserReportRequest extends z.TypeOf<typeof UserReportRequest> {
}

/**
 * AUTO GENERATED
 */

declare class UserAction$ {
    private axiosInstance;
    private namespace;
    private cache;
    constructor(axiosInstance: AxiosInstance, namespace: string, cache?: boolean);
    /**
     * This API is used to report a game user.&lt;p&gt;Other detail info: &lt;ul&gt;&lt;li&gt;&lt;i&gt;Required permission&lt;/i&gt;: resource=&#34;NAMESPACE:{namespace}:USER:{userId}:ACTION&#34;, action=1 (CREATE)&lt;/li&gt;&lt;/ul&gt;
     */
    createActionReport_ByUserId(userId: string, data: UserReportRequest): Promise<IResponse<unknown>>;
}

/**
 * AUTO GENERATED
 */

declare function UserActionApi(sdk: AccelbyteSDK, args?: ApiArgs): {
    createActionReport_ByUserId: (userId: string, data: UserReportRequest) => Promise<unknown>;
};

/**
 * AUTO GENERATED
 */

declare const Basic: {
    MiscApi: typeof MiscApi;
    NamespaceApi: typeof NamespaceApi;
    UserProfileApi: typeof UserProfileApi;
    FileUploadApi: typeof FileUploadApi;
    UserActionApi: typeof UserActionApi;
};

declare const ADtoForUnbanUserApiCall: z.ZodObject<{
    comment: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userIds: z.ZodArray<z.ZodString, "many">;
}, "strip", z.ZodTypeAny, {
    comment?: string | null | undefined;
    userIds: string[];
}, {
    comment?: string | null | undefined;
    userIds: string[];
}>;
interface ADtoForUnbanUserApiCall extends z.TypeOf<typeof ADtoForUnbanUserApiCall> {
}

declare const ADtoForUpdateEqu8ConfigApiCall: z.ZodObject<{
    apiKey: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    apiKey?: string | null | undefined;
}, {
    apiKey?: string | null | undefined;
}>;
interface ADtoForUpdateEqu8ConfigApiCall extends z.TypeOf<typeof ADtoForUpdateEqu8ConfigApiCall> {
}

declare const ADtoObjectForEqu8UserBanStatus: z.ZodObject<{
    expires: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    userId?: string | null | undefined;
    expires?: string | null | undefined;
}, {
    userId?: string | null | undefined;
    expires?: string | null | undefined;
}>;
interface ADtoObjectForEqu8UserBanStatus extends z.TypeOf<typeof ADtoObjectForEqu8UserBanStatus> {
}

declare const ADtoObjectForEqu8UserStatus: z.ZodObject<{
    actionComment: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    actionId: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    expires: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    when: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    userId?: string | null | undefined;
    expires?: string | null | undefined;
    actionComment?: string | null | undefined;
    actionId?: number | null | undefined;
    when?: string | null | undefined;
}, {
    userId?: string | null | undefined;
    expires?: string | null | undefined;
    actionComment?: string | null | undefined;
    actionId?: number | null | undefined;
    when?: string | null | undefined;
}>;
interface ADtoObjectForEqu8UserStatus extends z.TypeOf<typeof ADtoObjectForEqu8UserStatus> {
}

declare const Action: z.ZodObject<{
    color: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    description: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    duration: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    icon: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    id: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
    name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    priority: z.ZodNullable<z.ZodOptional<z.ZodNumber>>;
}, "strip", z.ZodTypeAny, {
    description?: string | null | undefined;
    color?: string | null | undefined;
    duration?: number | null | undefined;
    icon?: string | null | undefined;
    id?: number | null | undefined;
    name?: string | null | undefined;
    priority?: number | null | undefined;
}, {
    description?: string | null | undefined;
    color?: string | null | undefined;
    duration?: number | null | undefined;
    icon?: string | null | undefined;
    id?: number | null | undefined;
    name?: string | null | undefined;
    priority?: number | null | undefined;
}>;
interface Action extends z.TypeOf<typeof Action> {
}

declare const AddCountryGroupRequest: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface AddCountryGroupRequest extends z.TypeOf<typeof AddCountryGroupRequest> {
}

declare const AddCountryGroupResponse: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface AddCountryGroupResponse extends z.TypeOf<typeof AddCountryGroupResponse> {
}

declare const ConfigCreate: z.ZodObject<{
    key: z.ZodString;
    value: z.ZodString;
}, "strip", z.ZodTypeAny, {
    value: string;
    key: string;
}, {
    value: string;
    key: string;
}>;
interface ConfigCreate extends z.TypeOf<typeof ConfigCreate> {
}

declare const ConfigInfo: z.ZodObject<{
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    key: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    value: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    value?: string | null | undefined;
    namespace?: string | null | undefined;
    createdAt?: string | null | undefined;
    updatedAt?: string | null | undefined;
    key?: string | null | undefined;
}, {
    value?: string | null | undefined;
    namespace?: string | null | undefined;
    createdAt?: string | null | undefined;
    updatedAt?: string | null | undefined;
    key?: string | null | undefined;
}>;
interface ConfigInfo extends z.TypeOf<typeof ConfigInfo> {
}

declare const ConfigUpdate: z.ZodObject<{
    value: z.ZodString;
}, "strip", z.ZodTypeAny, {
    value: string;
}, {
    value: string;
}>;
interface ConfigUpdate extends z.TypeOf<typeof ConfigUpdate> {
}

declare const CountryGroupObject: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface CountryGroupObject extends z.TypeOf<typeof CountryGroupObject> {
}

declare const CountryObject: z.ZodObject<{
    code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}, {
    code?: string | null | undefined;
    name?: string | null | undefined;
}>;
interface CountryObject extends z.TypeOf<typeof CountryObject> {
}

declare const Equ8Config: z.ZodObject<{
    apiKey: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    namespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    namespace?: string | null | undefined;
    apiKey?: string | null | undefined;
}, {
    namespace?: string | null | undefined;
    apiKey?: string | null | undefined;
}>;
interface Equ8Config extends z.TypeOf<typeof Equ8Config> {
}

declare const ErrorEntity: z.ZodObject<{
    devStackTrace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorCode: z.ZodNumber;
    errorMessage: z.ZodString;
    messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    devStackTrace?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorCode: number;
    errorMessage: string;
}, {
    devStackTrace?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorCode: number;
    errorMessage: string;
}>;
interface ErrorEntity extends z.TypeOf<typeof ErrorEntity> {
}

declare const FieldValidationError: z.ZodObject<{
    errorCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorField: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorMessage: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    errorValue: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
}, "strip", z.ZodTypeAny, {
    errorCode?: string | null | undefined;
    errorMessage?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorField?: string | null | undefined;
    errorValue?: string | null | undefined;
}, {
    errorCode?: string | null | undefined;
    errorMessage?: string | null | undefined;
    messageVariables?: Record<string, string> | null | undefined;
    errorField?: string | null | undefined;
    errorValue?: string | null | undefined;
}>;
interface FieldValidationError extends z.TypeOf<typeof FieldValidationError> {
}

declare const NamespaceCreate: z.ZodObject<{
    displayName: z.ZodString;
    namespace: z.ZodString;
}, "strip", z.ZodTypeAny, {
    namespace: string;
    displayName: string;
}, {
    namespace: string;
    displayName: string;
}>;
interface NamespaceCreate extends z.TypeOf<typeof NamespaceCreate> {
}

declare const NamespaceInfo: z.ZodObject<{
    clientId: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    createdAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    displayName: z.ZodString;
    namespace: z.ZodString;
    parentNamespace: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "DELETED", "INACTIVE"]>>>;
    updatedAt: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}, {
    status?: "ACTIVE" | "DELETED" | "INACTIVE" | null | undefined;
    clientId?: string | null | undefined;
    createdAt?: string | null | undefined;
    parentNamespace?: string | null | undefined;
    updatedAt?: string | null | undefined;
    namespace: string;
    displayName: string;
}>;
interface NamespaceInfo extends z.TypeOf<typeof NamespaceInfo> {
}

declare const NamespaceStatusUpdate: z.ZodObject<{
    status: z.ZodEnum<["ACTIVE", "INACTIVE"]>;
}, "strip", z.ZodTypeAny, {
    status: "ACTIVE" | "INACTIVE";
}, {
    status: "ACTIVE" | "INACTIVE";
}>;
interface NamespaceStatusUpdate extends z.TypeOf<typeof NamespaceStatusUpdate> {
}

declare const NamespaceUpdate: z.ZodObject<{
    displayName: z.ZodString;
}, "strip", z.ZodTypeAny, {
    displayName: string;
}, {
    displayName: string;
}>;
interface NamespaceUpdate extends z.TypeOf<typeof NamespaceUpdate> {
}

declare const RetrieveCountryGroupResponse: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupCode?: string | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface RetrieveCountryGroupResponse extends z.TypeOf<typeof RetrieveCountryGroupResponse> {
}

declare const UpdateCountryGroupRequest: z.ZodObject<{
    countries: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        code: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        name: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    }, "strip", z.ZodTypeAny, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }, {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }>, "many">>>;
    countryGroupName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupName?: string | null | undefined;
}, {
    countries?: {
        code?: string | null | undefined;
        name?: string | null | undefined;
    }[] | null | undefined;
    countryGroupName?: string | null | undefined;
}>;
interface UpdateCountryGroupRequest extends z.TypeOf<typeof UpdateCountryGroupRequest> {
}

declare const UserBanRequest: z.ZodObject<{
    actionId: z.ZodNumber;
    comment: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    userIds: z.ZodArray<z.ZodString, "many">;
}, "strip", z.ZodTypeAny, {
    comment?: string | null | undefined;
    userIds: string[];
    actionId: number;
}, {
    comment?: string | null | undefined;
    userIds: string[];
    actionId: number;
}>;
interface UserBanRequest extends z.TypeOf<typeof UserBanRequest> {
}

declare const UserProfileAdmin: z.ZodObject<{
    avatarLargeUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarSmallUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    avatarUrl: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    customAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    dateOfBirth: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    firstName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    language: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    lastName: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    privateCustomAttributes: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>>;
    status: z.ZodNullable<z.ZodOptional<z.ZodEnum<["ACTIVE", "INACTIVE"]>>>;
    timeZone: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    zipCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
}, "strip", z.ZodTypeAny, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}, {
    status?: "ACTIVE" | "INACTIVE" | null | undefined;
    avatarLargeUrl?: string | null | undefined;
    avatarSmallUrl?: string | null | undefined;
    avatarUrl?: string | null | undefined;
    customAttributes?: Record<string, any> | null | undefined;
    dateOfBirth?: string | null | undefined;
    firstName?: string | null | undefined;
    language?: string | null | undefined;
    lastName?: string | null | undefined;
    timeZone?: string | null | undefined;
    zipCode?: string | null | undefined;
    privateCustomAttributes?: Record<string, any> | null | undefined;
}>;
interface UserProfileAdmin extends z.TypeOf<typeof UserProfileAdmin> {
}

declare const UserProfileBulkRequest: z.ZodObject<{
    userIds: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
}, "strip", z.ZodTypeAny, {
    userIds?: string[] | null | undefined;
}, {
    userIds?: string[] | null | undefined;
}>;
interface UserProfileBulkRequest extends z.TypeOf<typeof UserProfileBulkRequest> {
}

declare const ValidationErrorEntity: z.ZodObject<{
    errorCode: z.ZodNumber;
    errorMessage: z.ZodString;
    errors: z.ZodNullable<z.ZodOptional<z.ZodArray<z.ZodObject<{
        errorCode: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorField: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorMessage: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        errorValue: z.ZodNullable<z.ZodOptional<z.ZodString>>;
        messageVariables: z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>;
    }, "strip", z.ZodTypeAny, {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }, {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }>, "many">>>;
}, "strip", z.ZodTypeAny, {
    errors?: {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }[] | null | undefined;
    errorCode: number;
    errorMessage: string;
}, {
    errors?: {
        errorCode?: string | null | undefined;
        errorMessage?: string | null | undefined;
        messageVariables?: Record<string, string> | null | undefined;
        errorField?: string | null | undefined;
        errorValue?: string | null | undefined;
    }[] | null | undefined;
    errorCode: number;
    errorMessage: string;
}>;
interface ValidationErrorEntity extends z.TypeOf<typeof ValidationErrorEntity> {
}

export { ADtoForUnbanUserApiCall, ADtoForUpdateEqu8ConfigApiCall, ADtoObjectForEqu8UserBanStatus, ADtoObjectForEqu8UserStatus, Action, AddCountryGroupRequest, AddCountryGroupResponse, Basic, ConfigCreate, ConfigInfo, ConfigUpdate, CountryGroupObject, CountryObject, Equ8Config, ErrorEntity, FieldValidationError, FileUpload$, FileUploadApi, FileUploadUrlInfo, Misc$, MiscApi, Namespace$, NamespaceApi, NamespaceCreate, NamespaceInfo, NamespaceInfoArray, NamespacePublisherInfo, NamespaceStatusUpdate, NamespaceUpdate, RetrieveCountryGroupResponse, RetrieveTimeResponse, UpdateCountryGroupRequest, UserAction$, UserActionApi, UserBanRequest, UserProfile$, UserProfileAdmin, UserProfileApi, UserProfileBulkRequest, UserProfileCreate, UserProfileInfo, UserProfilePrivateCreate, UserProfilePrivateInfo, UserProfilePublicInfo, UserProfilePublicInfoArray, UserProfileStatusUpdate, UserProfileUpdate, UserReportRequest, UserZipCode, UserZipCodeUpdate, ValidationErrorEntity };
